==> ogre-14.3.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_bullet_8h.js <==
var _ogre_bullet_8h =
[
    [ "Ogre::Bullet::ColliderType", "group___bullet.html#ga3830c02915732639d36dd2f7aa7b6d98", [
      [ "Ogre::Bullet::CT_BOX", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6921eaed31121d358c650acc966f968e", null ],
      [ "Ogre::Bullet::CT_SPHERE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98aee31fba153630d145e0f5ca59daf6963", null ],
      [ "Ogre::Bullet::CT_CYLINDER", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6e2834b721b1bf5444d685379e6a1031", null ],
      [ "Ogre::Bullet::CT_CAPSULE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a073e87fdfdfabb19755f1defcbe1bb78", null ],
      [ "Ogre::Bullet::CT_TRIMESH", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a4c72346edc69af82d8ee74e32f0f19d9", null ],
      [ "Ogre::Bullet::CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ]
    ] ],
    [ "Ogre::Bullet::convert", "group___bullet.html#gae507a0bfafc7f585d0270d7445767065", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#ga6e488b2065b2f2daea503cfb2d7b7c0a", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#ga785efc9c1547e151c87e3481e3b0eec3", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#gacb757bd2267d2c511e87f54002bc74dd", null ],
    [ "Ogre::Bullet::createSphereCollider", "group___bullet.html#ga4816ec507132c27c52b40dab60c6ba87", null ],
    [ "Ogre::Bullet::createBoxCollider", "group___bullet.html#ga508ce5259dc72353adaf458c9a1165bd", null ],
    [ "Ogre::Bullet::createCapsuleCollider", "group___bullet.html#ga4f6fa3c86ab9ac184a2149768002991d", null ],
    [ "Ogre::Bullet::createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ]
];

==> ogre-14.4.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_bullet_8h.js <==
var _ogre_bullet_8h =
[
    [ "Ogre::Bullet::ColliderType", "group___bullet.html#ga3830c02915732639d36dd2f7aa7b6d98", [
      [ "Ogre::Bullet::CT_BOX", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6921eaed31121d358c650acc966f968e", null ],
      [ "Ogre::Bullet::CT_SPHERE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98aee31fba153630d145e0f5ca59daf6963", null ],
      [ "Ogre::Bullet::CT_CYLINDER", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a6e2834b721b1bf5444d685379e6a1031", null ],
      [ "Ogre::Bullet::CT_CAPSULE", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a073e87fdfdfabb19755f1defcbe1bb78", null ],
      [ "Ogre::Bullet::CT_TRIMESH", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a4c72346edc69af82d8ee74e32f0f19d9", null ],
      [ "Ogre::Bullet::CT_HULL", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a3a55904467ef9e191aedbf08f5ca67e2", null ],
      [ "Ogre::Bullet::CT_COMPOUND", "group___bullet.html#gga3830c02915732639d36dd2f7aa7b6d98a93188a275f493576a9744fa6738198f8", null ]
    ] ],
    [ "Ogre::Bullet::convert", "group___bullet.html#gae507a0bfafc7f585d0270d7445767065", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#ga6e488b2065b2f2daea503cfb2d7b7c0a", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#ga785efc9c1547e151c87e3481e3b0eec3", null ],
    [ "Ogre::Bullet::convert", "group___bullet.html#gacb757bd2267d2c511e87f54002bc74dd", null ],
    [ "Ogre::Bullet::createSphereCollider", "group___bullet.html#ga4816ec507132c27c52b40dab60c6ba87", null ],
    [ "Ogre::Bullet::createBoxCollider", "group___bullet.html#ga508ce5259dc72353adaf458c9a1165bd", null ],
    [ "Ogre::Bullet::createCapsuleCollider", "group___bullet.html#ga4f6fa3c86ab9ac184a2149768002991d", null ],
    [ "Ogre::Bullet::createCylinderCollider", "group___bullet.html#ga9dd4ceac77c2c6b52bc8e659fa39d82c", null ],
    [ "Ogre::Bullet::createTrimeshCollider", "group___bullet.html#gaed45b1c7e0ab58c9a0126671ab47c5cc", null ],
    [ "Ogre::Bullet::createConvexHullCollider", "group___bullet.html#ga4b0184ec77d0e75daaf8e55fd8b90965", null ],
    [ "Ogre::Bullet::createCompoundShape", "group___bullet.html#gab62b4f5293ae739167b3b22688d53b27", null ],
    [ "Ogre::Bullet::createHeightfieldTerrainShape", "group___bullet.html#ga4f8524c5a233db7cae27d5b9bc90db05", null ]
];
